import argparse
from athena_history_gnuplot import readData
from prettytable import PrettyTable

def evalQuantity(sim_data,quantity,scale):
  eval_data  = sim_data.eval(quantity)
  eval_data *= scale
  quants = {}
  quants["mean"] = "{:.3e}".format(eval_data.mean())
  quants["max"]  = "{:.3e}".format(eval_data.max())
  quants["min"]  = "{:.3e}".format(eval_data.min())
  return quants

def main(**kwargs):
  hst_results = []
  for file in kwargs["hst_filenames"]:
    data = readData(file)
    quants = evalQuantity(data,kwargs["quantity"],kwargs["scale"])
    quants["filename"] = file
    hst_results.append(quants)
  
  tab = PrettyTable()
  tab.field_names = ["Model","Mean","Max","Min"]
  for result in hst_results:
    tab.add_row([result["filename"],result["mean"],result["max"],result["min"]])
  print("\n> Results for models with parameter {} with scale of {:3e}\n".format(kwargs["quantity"],kwargs["scale"]))
  print(tab)
  

if __name__ == "__main__":
  parser = argparse.ArgumentParser(description = "Get statistical properties of parameters in an athena history file")
  parser.add_argument("quantity",
                       help = "Parameter to assess, evalquantity is used to parse")
  parser.add_argument("scale",
                       type=float,
                       help = "Scale for result parameter")
  parser.add_argument("hst_filenames",
                      nargs="*",
                      help="Filenames of .hst files")
  args = parser.parse_args()
  main(**vars(args))